@@ -2,7 +2,7 @@ use 5.006;
 use strict;
 use warnings;
 package Muldis::D;
-our $VERSION = '0.129001';
+our $VERSION = '0.130000';
 $VERSION = eval $VERSION;
 # Note that Perl code only exists at all in this file in order to help
 # the CPAN indexer handle the distribution properly.
@@ -20,7 +20,7 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Muldis::D version 0.129.1.
+This document is Muldis::D version 0.130.0.
 
 =head1 PREFACE
 
@@ -45,9 +45,9 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<Muldis_D:"http://muldis.com":0.129.1>.  It is the official/original (not
+C<Muldis_D:"http://muldis.com":0.130.0>.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Darren Duncan (C<http://muldis.com>), version C<0.129.1> (this number
+Darren Duncan (C<http://muldis.com>), version C<0.130.0> (this number
 matches the VERSION pod in this file).  This multi-part document is named
 and organized with the expectation that many dialects, extensions, and core
 versions of it will exist over time, some of those under the original
@@ -354,37 +354,49 @@ None yet.
 
 =head1 FORUMS
 
-Several public email-based forums exist whose main topic is all
-implementations of the L<Muldis D|Muldis::D> language, especially the
-L<Muldis Rosetta|Muldis::Rosetta> reference implementation, but also the
-L<Set::Relation> module.  All of these you can reach via
+Several public email-based forums exist whose main topic is
+the L<Muldis D|Muldis::D> language and its implementations, especially
+the L<Muldis Rosetta|Muldis::Rosetta> reference implementation, but also
+the L<Set::Relation> module.  They exist so that users of Muldis D or
+Muldis Rosetta can help each other, or so that help coming from the
+projects' developers can be said once to many people, rather than
+necessarily to each individually.  All of these you can reach via
 L<http://mm.darrenduncan.net/mailman/listinfo>; go there to manage your
 subscriptions to, or view the archives of, the following:
 
 =over
 
-=item C<muldis-db-announce@mm.DarrenDuncan.net>
+=item C<muldis-db-announce@mm.darrenduncan.net>
 
-This low-volume list is mainly for official announcements from the Muldis
-Rosetta developers, though developers of Muldis Rosetta extensions can also
+This low-volume list is mainly for official announcements from Muldis D or
+Muldis Rosetta developers, though developers of related projects can also
 post their announcements here.  This is not a discussion list.
 
-=item C<muldis-db-users@mm.DarrenDuncan.net>
+=item C<muldis-db-users@mm.darrenduncan.net>
 
-This list is for general discussion among people who are using Muldis
-Rosetta, which is not concerned with the implementation of Muldis Rosetta
-itself.  This is the best place to ask for basic help in getting Muldis
-Rosetta installed on your machine or to make it do what you want.  You
-could also submit feature requests or report perceived bugs here, if you
-don't want to use CPAN's RT system.
+This list is for general discussion among people who are using Muldis D or
+any of its implementations, especially the Muldis Rosetta reference
+implementation.  This is the best place to ask for basic help in getting
+Muldis Rosetta installed on your machine or to make it do what you want.
+If you are in doubt on which list to use, then use this one by default.
+You could also submit feature requests for Muldis Rosetta or report
+perceived bugs here, if you don't want to use CPAN's RT system.
 
-=item C<muldis-db-devel@mm.DarrenDuncan.net>
+=item C<muldis-d-language@mm.darrenduncan.net>
+
+This list is mainly for discussion among people who are designing the
+Muldis D language specification, or who are implementing or adapting Muldis
+D in some form, or who are writing Muldis D documentation, tests, or
+examples.  It is not the main forum for any Muldis D implementations, nor
+is it the place for non-implementers to get help in using said.
+
+=item C<muldis-db-devel@mm.darrenduncan.net>
 
 This list is for discussion among people who are designing or implementing
-the Muldis Rosetta core API (including Muldis D language design), or who
-are implementing Muldis Rosetta Engines, or who are writing core
-documentation, tests, or examples.  It is not the place for
-non-implementers to get help in using said.
+the Muldis Rosetta DBMS framework core, or who are implementing Muldis
+Rosetta Engines, or who are writing Muldis Rosetta core documentation,
+tests, or examples.  It is not the main forum for the Muldis D language
+itself, nor is it the place for non-implementers to get help in using said.
 
 =back
 
